@@ -1,5 +1,6 @@
 """
 This is a subscriber meant for the 'weather' messages example.
+It uses a callback to process incoming messages.
 """
 from __future__ import print_function
 import sys
@@ -14,7 +15,7 @@ if sys.version_info < (3, 0):
 Pyro4.config.AUTOPROXY = True
 
 
-@Pyro4.expose()
+@Pyro4.expose
 class Subber(Subscriber):
     def consume_message(self, topic, message):
         # This callback-method is called automatically when a message arrives on the bus.
