@@ -1,6 +1,8 @@
 from __future__ import print_function
+import Pyro4
 
 
+@Pyro4.expose
 class ShoppingCart(object):
     def __init__(self):
         self.contents = []
