@@ -47,7 +47,7 @@ class URI(object):
     You can write the protocol in lowercase if you like (``pyro:...``) but it will
     automatically be converted to uppercase internally.
     """
-    uriRegEx = re.compile(r"(?P<protocol>[Pp][Yy][Rr][Oo][a-zA-Z]*):(?P<object>\S+?)(@(?P<location>\S+))?$")
+    uriRegEx = re.compile(r"(?P<protocol>[Pp][Yy][Rr][Oo][a-zA-Z]*):(?P<object>\S+?)(@(?P<location>.+))?$")
 
     def __init__(self, uri):
         if isinstance(uri, URI):
@@ -663,7 +663,9 @@ class Proxy(object):
 
     def _pyroAsync(self, asynchronous=True):
         """turns the proxy into asynchronous mode so you can do asynchronous method calls,
-        or sets it back to normal sync mode if you set asynchronous=False."""
+        or sets it back to normal sync mode if you set asynchronous=False.
+        This setting is strictly on a per-proxy basis (unless an exact clone is made
+        via copy.copy)."""
         self.__async = asynchronous
 
     if sys.version_info < (3, 7):
@@ -990,7 +992,7 @@ def expose(method_or_class):
         if inspect.ismethoddescriptor(method_or_class):
             attrname = method_or_class.__get__(None, dict).__name__
             raise AttributeError("using @expose on a classmethod/staticmethod must be done "
-                                 "after @classmethod/@taticmethod. Method: " + attrname)
+                                 "after @classmethod/@staticmethod. Method: " + attrname)
         else:
             raise AttributeError("@expose cannot determine what this is: " + repr(method_or_class))
     if util.is_private_attribute(attrname):
@@ -1002,7 +1004,7 @@ def expose(method_or_class):
             if util.is_private_attribute(name):
                 continue
             thing = getattr(clazz, name)
-            if inspect.isfunction(thing):
+            if inspect.isfunction(thing) or inspect.ismethoddescriptor(thing):
                 thing._pyroExposed = True
             elif inspect.ismethod(thing):
                 thing.__func__._pyroExposed = True
@@ -1113,8 +1115,8 @@ class Daemon(object):
                 host = config.HOST
             if nathost is None:
                 nathost = config.NATHOST
-            if natport is None:
-                natport = config.NATPORT or None
+            if natport is None and nathost is not None:
+                natport = config.NATPORT
             if nathost and unixsocket:
                 raise ValueError("cannot use nathost together with unixsocket")
             if (nathost is None) ^ (natport is None):
